graph
------------------------

.. automodule:: flax.nnx
.. currentmodule:: flax.nnx


.. autofunction:: split
.. autofunction:: merge
.. autofunction:: update
.. autofunction:: pop
.. autofunction:: state
.. autofunction:: graphdef
.. autofunction:: iter_graph
.. autofunction:: clone

.. autoclass:: GraphDef
  :members:

.. autoclass:: UpdateContext
  :members:

.. autofunction:: update_context
.. autofunction:: current_update_context